#Abilities
from .ReportAbilities import Get_AbilityList
from .ReportAbilities import Get_Data_Ability

#Damage Done
from .ReportEventsDamageDone import Get_Data_EventDamageDone

#Death
from .ReportEventsDeath import Get_Data_EventDeath

#Interrupts
from .ReportEventsInterrupts import Get_Data_EventInterrupts

#Names
from .ReportNames import Get_Data_Name
from .ReportNames import Get_NameList


import requests
import json

"""query string to get names from given event"""
queryName = """query($code:String){
                reportData{
                    report(code:$code){
                        masterData(translate:false){
                            actors(type:"Player"){
                                id
                                name
                            }
                        }
                    }
                }
            }"""

"""Gets the data 'actors' from GraphQL api. Require response, auth-url and event string"""
def Get_Data_Name(response, publicURL, **kwargs):
    data = {"query": queryName, "variables": kwargs}
    with requests.Session() as session:
        session.headers = response
        response = session.get(publicURL, json= data)
    return response.json()

"""Gets the data 'actors' from GraphQL api as a list. Require response, auth-url and event string"""
def Get_NameList(response,publicURL, **kwargs):
    response = Get_Data_Name(response, publicURL, **kwargs)['data']['reportData']['report']['masterData']
    returnList = []
    for plr in response['actors']:
        returnList.append((plr['id'],plr['name']))
    return returnList



import requests
import json
from gql_query_builder import GqlQuery


"""query string to get events from given event"""
queryDeath = """query($code:String){
                    reportData{
                        report(code:$code){
                            events(dataType: Deaths, endTime:9999999999999,  wipeCutoff: 3){
                                data
                            }
                        }
                    }
                }"""

"""query($code: String){
    reportData{
        report(code: $code){
            events(dataType: Deaths, endTime: 9999999999999, wipeCutoff: 3){
                data
            }
        }
    }
}
"""

#newQueryDeath
event_field = GqlQuery().fields(['data']).query('events', input={'dataType' : 'Deaths', 'endTime' : '9999999999999', 'wipeCutoff': '3'}).generate()
reportData_field = GqlQuery().fields([event_field]).query('report', input={'code' : '$code'}).operation('reportData').generate()
new_queryDeath = GqlQuery().fields([reportData_field]).query('query', input={'$code' : 'String'}).generate()

#operation('query')


#dataType is an enum. Here it is used to get all death events.

"""Gets the data 'events' from GraphQL api. Require response, auth-url and event string"""
def Get_Data_EventDeath(response, publicURL, **kwargs):
    print(new_queryDeath)
    data = {"query": queryDeath, "variables": kwargs}
    with requests.Session() as session:
        session.headers = response
        response = session.get(publicURL, json= data)
    return response.json()

